==> nanopolish_0.8.1.orig.tar.gz: nanopolish-0.8.1/src/alignment/nanopolish_anchor.h <==
//---------------------------------------------------------
// Copyright 2015 Ontario Institute for Cancer Research
// Written by Jared Simpson (jared.simpson@oicr.on.ca)
//---------------------------------------------------------
//
// nanopolish_anchor - a collection of data types
// for representing a set of event-to-sequence
// mappings.
#ifndef NANOPOLISH_ANCHOR_H
#define NANOPOLISH_ANCHOR_H

#include <memory>
#include "htslib/hts.h"
#include "htslib/sam.h"
#include "nanopolish_common.h"
#include "nanopolish_squiggle_read.h"

struct AlignedPair
{
    int ref_pos;
    int read_pos;
};

struct AlignedPairRefLBComp
{
    bool operator()(const AlignedPair& o, int v) { return o.ref_pos < v; }
};

struct AlignedPairRefUBComp
{
    bool operator()(int v, const AlignedPair& o) { return v < o.ref_pos; }
};

// typedefs
typedef std::vector<AlignedPair>::iterator AlignedPairIter;
typedef std::vector<AlignedPair>::const_iterator AlignedPairConstIter;

// An event index and orientation that gives us a handle
// into the event sequence for some SquiggleRead
struct HMMStrandAnchor
{
    //
    HMMStrandAnchor() : event_idx(-1), rc(false) {}
    HMMStrandAnchor(int ei, bool f) : event_idx(ei), rc(f) {}

    //
    int event_idx;
    bool rc; // with respect to consensus
};

// A pair of vectors containing all of the anchors
// for both strands of a SquiggleRead
struct HMMReadAnchorSet
{
    std::vector<HMMStrandAnchor> strand_anchors[NUM_STRANDS];
};

// This data structure represents a column of a 
// multiple alignment where the base sequence
// is a subsequence of a contig that we
// we have mapped events to. It also holds alternative
// sequences sampled from the reads at starting at this column.
struct HMMAnchoredColumn
{
    std::string base_sequence;
    std::vector<HMMStrandAnchor> anchors;
    std::vector<std::string> alt_sequences;

    // reference name and coordinate for the segment
    std::string base_contig;
    size_t base_start_position;
};

//
struct HMMRealignmentInput
{
    std::vector<std::unique_ptr<SquiggleRead> > reads;
    std::vector<HMMAnchoredColumn> anchored_columns;
    std::string original_sequence;
};

// Return a vector specifying pairs of bases that have been aligned to each other
// This function can handle an "event cigar" bam record, which requires the ability
// for event indices to be in ascending or descending order. In the latter case
// read_stride should be -1
std::vector<AlignedPair> get_aligned_pairs(const bam1_t* record, int read_stride = 1);

#endif

==> nanopolish_0.9.0.orig.tar.gz: nanopolish-0.9.0/src/alignment/nanopolish_anchor.h <==
//---------------------------------------------------------
// Copyright 2015 Ontario Institute for Cancer Research
// Written by Jared Simpson (jared.simpson@oicr.on.ca)
//---------------------------------------------------------
//
// nanopolish_anchor - a collection of data types
// for representing a set of event-to-sequence
// mappings.
#ifndef NANOPOLISH_ANCHOR_H
#define NANOPOLISH_ANCHOR_H

#include <memory>
#include "htslib/hts.h"
#include "htslib/sam.h"
#include "nanopolish_common.h"
#include "nanopolish_squiggle_read.h"

struct AlignedPair
{
    int ref_pos;
    int read_pos;
};

struct AlignedPairRefLBComp
{
    bool operator()(const AlignedPair& o, int v) { return o.ref_pos < v; }
};

struct AlignedPairRefUBComp
{
    bool operator()(int v, const AlignedPair& o) { return v < o.ref_pos; }
};

// typedefs
typedef std::vector<AlignedPair>::iterator AlignedPairIter;
typedef std::vector<AlignedPair>::const_iterator AlignedPairConstIter;

// Return a vector specifying read-to-reference alignment segments
// Each segment contains a vector pairs of bases that have been aligned to each other.
// Each segment is defined a sequence of cigar match/ins/deletion options, followed by
// a reference skip (N) operation.
// This function can handle an "event cigar" bam record, which requires the ability
// for event indices to be in ascending or descending order. In the latter case
// read_stride should be -1
typedef std::vector<AlignedPair> AlignedSegment;
std::vector<AlignedSegment> get_aligned_segments(const bam1_t* record, int read_stride = 1);

#endif
